Resampler
==========

.. automodule:: stonesoup.resampler
    :no-members:

.. automodule:: stonesoup.resampler.base
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.resampler.particle
    :show-inheritance:
